PlaidLinkFlutterPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- PlaidLinkFlutterPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onEvent
→ Stream<
LinkEvent> -
no setter
-
onExit
→ Stream<
LinkExit> -
no setter
-
onLoad
→ Stream<
void> -
no setter
-
onSuccess
→ Stream<
LinkSuccess> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPlaidHeadlessSession(
String token, int sessionId) → Future< void> -
createPlaidLayerSession(
String token, int sessionId) → Future< void> -
createPlaidLinkSession(
String token, int sessionId) → Future< void> -
embeddedExitEvents(
int viewId) → Stream< LinkExit> -
embeddedLinkEvents(
int viewId) → Stream< LinkEvent> -
embeddedLoadEvents(
int viewId) → Stream< void> -
embeddedSuccessEvents(
int viewId) → Stream< LinkSuccess> -
getSdkVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onEventForSession(
int sessionId) → Stream< LinkEvent> -
onExitForSession(
int sessionId) → Stream< LinkExit> -
onLoadForSession(
int sessionId) → Stream< void> -
onSuccessForSession(
int sessionId) → Stream< LinkSuccess> -
openLayerSession(
) → Future< void> -
openLinkSession(
bool fullScreen) → Future< void> -
startHeadlessSession(
) → Future< void> -
submitLayerData(
SubmissionData data) → Future< void> -
syncFinanceKit(
FinanceKitConfiguration config) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ PlaidLinkFlutterPlatform
-
getter/setter pair